@@ -433,7 +433,7 @@ REDO:
 						v->get_statusline().show_error(strprintf::fmt(
 								_("Error: couldn't "
 									"parse filter "
-									"command `%s': %s"),
+									"expression `%s': %s"),
 								newfilter,
 								matcher.get_parse_error()));
 					} else {
@@ -630,9 +630,9 @@ void FeedListFormAction::set_feedlist(
 	update_form_title(width);
 }
 
-KeyMapHintEntry* FeedListFormAction::get_keymap_hint()
+const std::vector<KeyMapHintEntry>& FeedListFormAction::get_keymap_hint() const
 {
-	static KeyMapHintEntry hints[] = {{OP_QUIT, _("Quit")},
+	static const std::vector<KeyMapHintEntry> hints = {{OP_QUIT, _("Quit")},
 		{OP_OPEN, _("Open")},
 		{OP_NEXTUNREAD, _("Next Unread")},
 		{OP_RELOAD, _("Reload")},
@@ -640,8 +640,7 @@ KeyMapHintEntry* FeedListFormAction::get_keymap_hint()
 		{OP_MARKFEEDREAD, _("Mark Read")},
 		{OP_MARKALLFEEDSREAD, _("Mark All Read")},
 		{OP_SEARCH, _("Search")},
-		{OP_HELP, _("Help")},
-		{OP_NIL, nullptr}
+		{OP_HELP, _("Help")}
 	};
 	return hints;
 }
@@ -650,38 +649,29 @@ bool FeedListFormAction::jump_to_previous_unread_feed(unsigned int& feedpos)
 {
 	const unsigned int curpos = list.get_position();
 	LOG(Level::DEBUG,
-		"FeedListFormAction::jump_to_previous_unread_feed: searching "
-		"for "
-		"unread feed");
+		"FeedListFormAction::jump_to_previous_unread_feed: searching for unread feed");
 
 	for (int i = curpos - 1; i >= 0; --i) {
+		const auto unread = visible_feeds[i].first->unread_item_count();
 		LOG(Level::DEBUG,
-			"FeedListFormAction::jump_to_previous_unread_feed: "
-			"visible_feeds[%u] unread items: %u",
+			"FeedListFormAction::jump_to_previous_unread_feed: visible_feeds[%u] unread items: %u",
 			i,
-			visible_feeds[i].first->unread_item_count());
-		if (visible_feeds[i].first->unread_item_count() > 0) {
-			LOG(Level::DEBUG,
-				"FeedListFormAction::jump_to_previous_unread_"
-				"feed:"
-				" hit");
+			unread);
+		if (unread > 0) {
+			LOG(Level::DEBUG, "FeedListFormAction::jump_to_previous_unread_feed: hit");
 			list.set_position(i);
 			feedpos = visible_feeds[i].second;
 			return true;
 		}
 	}
-	for (int i = visible_feeds.size() - 1; i >= static_cast<int>(curpos);
-		--i) {
+	for (int i = visible_feeds.size() - 1; i >= static_cast<int>(curpos); --i) {
+		const auto unread = visible_feeds[i].first->unread_item_count();
 		LOG(Level::DEBUG,
-			"FeedListFormAction::jump_to_previous_unread_feed: "
-			"visible_feeds[%u] unread items: %u",
+			"FeedListFormAction::jump_to_previous_unread_feed: visible_feeds[%u] unread items: %u",
 			i,
-			visible_feeds[i].first->unread_item_count());
-		if (visible_feeds[i].first->unread_item_count() > 0) {
-			LOG(Level::DEBUG,
-				"FeedListFormAction::jump_to_previous_unread_"
-				"feed:"
-				" hit");
+			unread);
+		if (unread > 0) {
+			LOG(Level::DEBUG, "FeedListFormAction::jump_to_previous_unread_feed: hit");
 			list.set_position(i);
 			feedpos = visible_feeds[i].second;
 			return true;
@@ -739,36 +729,29 @@ bool FeedListFormAction::jump_to_next_unread_feed(unsigned int& feedpos)
 {
 	const unsigned int curpos = list.get_position();
 	LOG(Level::DEBUG,
-		"FeedListFormAction::jump_to_next_unread_feed: searching for "
-		"unread feed");
+		"FeedListFormAction::jump_to_next_unread_feed: searching for unread feed");
 
 	for (unsigned int i = curpos + 1; i < visible_feeds.size(); ++i) {
+		const auto unread = visible_feeds[i].first->unread_item_count();
 		LOG(Level::DEBUG,
-			"FeedListFormAction::jump_to_next_unread_feed: "
-			"visible_feeds[%u] unread items: %u",
+			"FeedListFormAction::jump_to_next_unread_feed: visible_feeds[%u] unread items: %u",
 			i,
-			visible_feeds[i].first->unread_item_count());
-		if (visible_feeds[i].first->unread_item_count() > 0) {
-			LOG(Level::DEBUG,
-				"FeedListFormAction::jump_to_next_unread_feed:"
-				" "
-				"hit");
+			unread);
+		if (unread > 0) {
+			LOG(Level::DEBUG, "FeedListFormAction::jump_to_next_unread_feed: hit");
 			list.set_position(i);
 			feedpos = visible_feeds[i].second;
 			return true;
 		}
 	}
-	for (unsigned int i = 0; i <= curpos; ++i) {
+	for (unsigned int i = 0; i <= curpos && i < visible_feeds.size(); ++i) {
+		const auto unread = visible_feeds[i].first->unread_item_count();
 		LOG(Level::DEBUG,
-			"FeedListFormAction::jump_to_next_unread_feed: "
-			"visible_feeds[%u] unread items: %u",
+			"FeedListFormAction::jump_to_next_unread_feed: visible_feeds[%u] unread items: %u",
 			i,
-			visible_feeds[i].first->unread_item_count());
-		if (visible_feeds[i].first->unread_item_count() > 0) {
-			LOG(Level::DEBUG,
-				"FeedListFormAction::jump_to_next_unread_feed:"
-				" "
-				"hit");
+			unread);
+		if (unread > 0) {
+			LOG(Level::DEBUG, "FeedListFormAction::jump_to_next_unread_feed: hit");
 			list.set_position(i);
 			feedpos = visible_feeds[i].second;
 			return true;
@@ -975,8 +958,9 @@ void FeedListFormAction::op_end_setfilter()
 	filterhistory.add_line(filtertext);
 	if (filtertext.length() > 0) {
 		if (!matcher.parse(filtertext)) {
-			v->get_statusline().show_error(
-				_("Error: couldn't parse filter command!"));
+			v->get_statusline().show_error(strprintf::fmt(
+					_("Error: couldn't parse filter expression `%s': %s"),
+					filtertext, matcher.get_parse_error()));
 		} else {
 			save_filterpos();
 			apply_filter = true;
