@@ -486,13 +486,20 @@ bool ItemListFormAction::process_operation(Operation op,
 		try {
 			const auto message_lifetime = v->get_statusline().show_message_until_finished(
 					_("Marking feed read..."));
+
 			std::vector<std::string> guids;
 			for (const auto& item : visible_items) {
 				const std::string guid = item.first->guid();
 				guids.push_back(guid);
 			}
 			rsscache->mark_items_read_by_guid(guids);
-			v->get_ctrl()->mark_all_read(guids);
+
+			if (apply_filter) {
+				// We're only viewing a subset of items, so mark them off one by one.
+				v->get_ctrl()->mark_all_read(guids);
+			} else {
+				v->get_ctrl()->mark_all_read(pos);
+			}
 
 			if (visible_items.size() > 0) {
 				std::lock_guard<std::mutex> lock(feed->item_mutex);
@@ -632,7 +639,7 @@ bool ItemListFormAction::process_operation(Operation op,
 						v->get_statusline().show_error(strprintf::fmt(
 								_("Error: couldn't "
 									"parse filter "
-									"command `%s': %s"),
+									"expression `%s': %s"),
 								newfilter,
 								matcher.get_parse_error()));
 					} else {
@@ -842,8 +849,9 @@ void ItemListFormAction::qna_end_setfilter()
 
 	if (filtertext.length() > 0) {
 		if (!matcher.parse(filtertext)) {
-			v->get_statusline().show_error(
-				_("Error: couldn't parse filter command!"));
+			v->get_statusline().show_error(strprintf::fmt(
+					_("Error: couldn't parse filter expression `%s': %s"),
+					filtertext, matcher.get_parse_error()));
 			return;
 		}
 
@@ -942,6 +950,29 @@ void ItemListFormAction::do_update_visible_items()
 		"ItemListFormAction::do_update_visible_items: size = %" PRIu64,
 		static_cast<uint64_t>(visible_items.size()));
 
+	const unsigned int pos = list.get_position();
+	unsigned int new_pos = pos;
+	for (unsigned int old_i = 0, new_i = 0;
+		old_i < visible_items.size() &&
+		new_i < new_visible_items.size() &&
+		old_i < pos; ) {
+		int cmp = visible_items[old_i].second < new_visible_items[new_i].second ? -1 :
+			(visible_items[old_i].second == new_visible_items[new_i].second ? 0 : 1);
+		if (cmp < 0) {
+			if (new_pos > 0) {
+				new_pos--;
+			}
+			old_i++;
+		} else if (cmp == 0) {
+			old_i++;
+			new_i++;
+		} else {
+			new_pos++;
+			new_i++;
+		}
+	}
+	list.set_position(new_pos);
+
 	visible_items = new_visible_items;
 }
 
@@ -1290,17 +1321,16 @@ std::string ItemListFormAction::get_guid()
 	return visible_items[itempos].first->guid();
 }
 
-KeyMapHintEntry* ItemListFormAction::get_keymap_hint()
+const std::vector<KeyMapHintEntry>& ItemListFormAction::get_keymap_hint() const
 {
-	static KeyMapHintEntry hints[] = {{OP_QUIT, _("Quit")},
+	static const std::vector<KeyMapHintEntry> hints = {{OP_QUIT, _("Quit")},
 		{OP_OPEN, _("Open")},
 		{OP_SAVE, _("Save")},
 		{OP_RELOAD, _("Reload")},
 		{OP_NEXTUNREAD, _("Next Unread")},
 		{OP_MARKFEEDREAD, _("Mark All Read")},
 		{OP_SEARCH, _("Search")},
-		{OP_HELP, _("Help")},
-		{OP_NIL, nullptr}
+		{OP_HELP, _("Help")}
 	};
 	return hints;
 }
