@@ -123,7 +123,6 @@ bool PbController::setup_dirs_xdg(const char* env_home)
 PbController::PbController()
 	: config_file("config")
 	, queue_file("queue")
-	, view_update_(true)
 	, max_dls(1)
 	, lock_file("pb-lock.pid")
 	, keys(KM_PODBOAT)
@@ -239,13 +238,11 @@ void PbController::initialize(int argc, char* argv[])
 	std::string error_message;
 	if (!fslock->try_lock(lock_file, pid, error_message)) {
 		if (pid != 0) {
-			// pid_t size could vary so cast to known integer format to get correct print format
-			std::int64_t p = pid;
 			std::cout << strprintf::fmt(
 					_("Error: an instance of %s is already "
-						"running (PID: %" PRId64 ")"),
+						"running (PID: %s)"),
 					"Podboat",
-					p)
+					std::to_string(pid))
 				<< std::endl;
 		} else {
 			std::cout << _("Error: ") << error_message << std::endl;
@@ -291,8 +288,8 @@ int PbController::run(PbView& v)
 
 	std::cout << _("done.") << std::endl;
 
-	ql.reset(new QueueLoader(queue_file, cfg, [this]() {
-		this->set_view_update_necessary(true);
+	ql.reset(new QueueLoader(queue_file, cfg, [&]() {
+		v.set_view_update_necessary();
 	}));
 	ql->reload(downloads_);
 
