@@ -455,7 +455,13 @@ std::shared_ptr<ItemListFormAction> View::push_itemlist(
 
 	feed->purge_deleted_items();
 
-	prepare_query_feed(feed);
+	try {
+		prepare_query_feed(feed);
+	} catch (const MatcherException& e) {
+		const auto msg = strprintf::fmt(_("Error: couldn't prepare query feed: %s"), e.what());
+		status_line.show_error(msg);
+		return nullptr;
+	}
 
 	if (feed->total_item_count() > 0) {
 		auto itemlist = std::make_shared<ItemListFormAction>(
@@ -700,7 +706,13 @@ bool View::get_random_unread(ItemListFormAction& itemlist,
 		LOG(Level::DEBUG,
 			"View::get_random_unread: found feed with unread "
 			"articles");
-		prepare_query_feed(feedlist_form->get_feed());
+		try {
+			prepare_query_feed(feedlist_form->get_feed());
+		} catch (const MatcherException& e) {
+			const auto msg = strprintf::fmt(_("Error: couldn't prepare query feed: %s"), e.what());
+			status_line.show_error(msg);
+			return false;
+		}
 		itemlist.set_feed(feedlist_form->get_feed());
 		itemlist.set_pos(feedpos);
 		itemlist.init();
@@ -741,7 +753,13 @@ bool View::get_previous_unread(ItemListFormAction& itemlist,
 		LOG(Level::DEBUG,
 			"View::get_previous_unread: found feed with unread "
 			"articles");
-		prepare_query_feed(feedlist_form->get_feed());
+		try {
+			prepare_query_feed(feedlist_form->get_feed());
+		} catch (const MatcherException& e) {
+			const auto msg = strprintf::fmt(_("Error: couldn't prepare query feed: %s"), e.what());
+			status_line.show_error(msg);
+			return false;
+		}
 		itemlist.set_feed(feedlist_form->get_feed());
 		itemlist.set_pos(feedpos);
 		itemlist.init();
@@ -761,7 +779,13 @@ bool View::get_next_unread_feed(ItemListFormAction& itemlist)
 {
 	unsigned int feedpos;
 	if (feedlist_form->jump_to_next_unread_feed(feedpos)) {
-		prepare_query_feed(feedlist_form->get_feed());
+		try {
+			prepare_query_feed(feedlist_form->get_feed());
+		} catch (const MatcherException& e) {
+			const auto msg = strprintf::fmt(_("Error: couldn't prepare query feed: %s"), e.what());
+			status_line.show_error(msg);
+			return false;
+		}
 		itemlist.set_feed(feedlist_form->get_feed());
 		itemlist.set_pos(feedpos);
 		itemlist.init();
@@ -774,7 +798,13 @@ bool View::get_prev_unread_feed(ItemListFormAction& itemlist)
 {
 	unsigned int feedpos;
 	if (feedlist_form->jump_to_previous_unread_feed(feedpos)) {
-		prepare_query_feed(feedlist_form->get_feed());
+		try {
+			prepare_query_feed(feedlist_form->get_feed());
+		} catch (const MatcherException& e) {
+			const auto msg = strprintf::fmt(_("Error: couldn't prepare query feed: %s"), e.what());
+			status_line.show_error(msg);
+			return false;
+		}
 		itemlist.set_feed(feedlist_form->get_feed());
 		itemlist.set_pos(feedpos);
 		itemlist.init();
@@ -806,7 +836,13 @@ bool View::get_next_unread(ItemListFormAction& itemlist,
 		LOG(Level::DEBUG,
 			"View::get_next_unread: found feed with unread "
 			"articles");
-		prepare_query_feed(feedlist_form->get_feed());
+		try {
+			prepare_query_feed(feedlist_form->get_feed());
+		} catch (const MatcherException& e) {
+			const auto msg = strprintf::fmt(_("Error: couldn't prepare query feed: %s"), e.what());
+			status_line.show_error(msg);
+			return false;
+		}
 		itemlist.set_feed(feedlist_form->get_feed());
 		itemlist.set_pos(feedpos);
 		itemlist.init();
@@ -839,7 +875,13 @@ bool View::get_previous(ItemListFormAction& itemlist,
 		status_line.show_error(_("Already on first item."));
 	} else if (feedlist_form->jump_to_previous_feed(feedpos)) {
 		LOG(Level::DEBUG, "View::get_previous: previous feed");
-		prepare_query_feed(feedlist_form->get_feed());
+		try {
+			prepare_query_feed(feedlist_form->get_feed());
+		} catch (const MatcherException& e) {
+			const auto msg = strprintf::fmt(_("Error: couldn't prepare query feed: %s"), e.what());
+			status_line.show_error(msg);
+			return false;
+		}
 		itemlist.set_feed(feedlist_form->get_feed());
 		itemlist.set_pos(feedpos);
 		itemlist.init();
@@ -871,7 +913,13 @@ bool View::get_next(ItemListFormAction& itemlist, ItemViewFormAction* itemview)
 		status_line.show_error(_("Already on last item."));
 	} else if (feedlist_form->jump_to_next_feed(feedpos)) {
 		LOG(Level::DEBUG, "View::get_next: next feed");
-		prepare_query_feed(feedlist_form->get_feed());
+		try {
+			prepare_query_feed(feedlist_form->get_feed());
+		} catch (const MatcherException& e) {
+			const auto msg = strprintf::fmt(_("Error: couldn't prepare query feed: %s"), e.what());
+			status_line.show_error(msg);
+			return false;
+		}
 		itemlist.set_feed(feedlist_form->get_feed());
 		itemlist.set_pos(feedpos);
 		itemlist.init();
@@ -891,7 +939,13 @@ bool View::get_next_feed(ItemListFormAction& itemlist)
 {
 	unsigned int feedpos;
 	if (feedlist_form->jump_to_next_feed(feedpos)) {
-		prepare_query_feed(feedlist_form->get_feed());
+		try {
+			prepare_query_feed(feedlist_form->get_feed());
+		} catch (const MatcherException& e) {
+			const auto msg = strprintf::fmt(_("Error: couldn't prepare query feed: %s"), e.what());
+			status_line.show_error(msg);
+			return false;
+		}
 		itemlist.set_feed(feedlist_form->get_feed());
 		itemlist.set_pos(feedpos);
 		itemlist.init();
@@ -904,7 +958,13 @@ bool View::get_prev_feed(ItemListFormAction& itemlist)
 {
 	unsigned int feedpos;
 	if (feedlist_form->jump_to_previous_feed(feedpos)) {
-		prepare_query_feed(feedlist_form->get_feed());
+		try {
+			prepare_query_feed(feedlist_form->get_feed());
+		} catch (const MatcherException& e) {
+			const auto msg = strprintf::fmt(_("Error: couldn't prepare query feed: %s"), e.what());
+			status_line.show_error(msg);
+			return false;
+		}
 		itemlist.set_feed(feedlist_form->get_feed());
 		itemlist.set_pos(feedpos);
 		itemlist.init();
