@@ -369,22 +369,88 @@ TEST_CASE("<embed>s are ignored if `type' is not set", "[HtmlRenderer]")
 	REQUIRE(links.size() == 0);
 }
 
+TEST_CASE("<iframe>s are added to links if `src' is set", "[HtmlRenderer]")
+{
+	HtmlRenderer r;
+
+	const std::string input(
+		"<iframe src=\"https://www.youtube.com/embed/0123456789A\""
+		"        width=\"640\" height=\"360\"></iframe>");
+	std::vector<std::pair<LineType, std::string>> lines;
+	std::vector<LinkPair> links;
+
+	REQUIRE_NOTHROW(r.render(input, lines, links, ""));
+	REQUIRE(lines.size() == 4);
+	REQUIRE(lines[0] == p(LineType::wrappable, "[iframe 1 (link #1)]"));
+	REQUIRE(lines[1] == p(LineType::wrappable, ""));
+	REQUIRE(lines[2] == p(LineType::wrappable, "Links: "));
+	REQUIRE(lines[3] == p(LineType::softwrappable,
+			"[1]: https://www.youtube.com/embed/0123456789A (iframe)"));
+	REQUIRE(links.size() == 1);
+	REQUIRE(links[0].first == "https://www.youtube.com/embed/0123456789A");
+	REQUIRE(links[0].second == LinkType::IFRAME);
+}
+
+TEST_CASE("<iframe>s are rendered with a title if `title' is set",
+	"[HtmlRenderer]")
+{
+	HtmlRenderer r;
+
+	const std::string input(
+		"<iframe src=\"https://www.youtube.com/embed/0123456789A\""
+		"        title=\"My Video\" width=\"640\" height=\"360\"></iframe>");
+	std::vector<std::pair<LineType, std::string>> lines;
+	std::vector<LinkPair> links;
+
+	REQUIRE_NOTHROW(r.render(input, lines, links, ""));
+	REQUIRE(lines.size() == 4);
+	REQUIRE(lines[0] == p(LineType::wrappable,
+			"[iframe 1: My Video (link #1)]"));
+	REQUIRE(lines[1] == p(LineType::wrappable, ""));
+	REQUIRE(lines[2] == p(LineType::wrappable, "Links: "));
+	REQUIRE(lines[3] == p(LineType::softwrappable,
+			"[1]: https://www.youtube.com/embed/0123456789A (iframe)"));
+	REQUIRE(links.size() == 1);
+	REQUIRE(links[0].first == "https://www.youtube.com/embed/0123456789A");
+	REQUIRE(links[0].second == LinkType::IFRAME);
+}
+
+TEST_CASE("<iframe>s are ignored if `src' is not set", "[HtmlRenderer]")
+{
+	HtmlRenderer r;
+
+	const std::string input(
+		"<iframe width=\"640\" height=\"360\"></iframe>");
+	std::vector<std::pair<LineType, std::string>> lines;
+	std::vector<LinkPair> links;
+
+	REQUIRE_NOTHROW(r.render(input, lines, links, ""));
+	REQUIRE(lines.size() == 0);
+	REQUIRE(links.size() == 0);
+}
+
 TEST_CASE("spaces and line breaks are preserved inside <pre>", "[HtmlRenderer]")
 {
 	HtmlRenderer r;
 
 	const std::string input =
 		"<pre>oh cool\n"
+		"\n"
 		"  check this\tstuff  out!\n"
+		"     \n"
+		"neat huh?\n"
 		"</pre>";
 	std::vector<std::pair<LineType, std::string>> lines;
 	std::vector<LinkPair> links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
-	REQUIRE(lines.size() == 2);
+	REQUIRE(lines.size() == 5);
 	REQUIRE(lines[0] == p(LineType::softwrappable, "oh cool"));
-	REQUIRE(lines[1] ==
+	REQUIRE(lines[1] == p(LineType::softwrappable, ""));
+	REQUIRE(lines[2] ==
 		p(LineType::softwrappable, "  check this\tstuff  out!"));
+	REQUIRE(lines[3] == p(LineType::softwrappable, "     "));
+	REQUIRE(lines[4] == p(LineType::softwrappable, "neat huh?"));
 	REQUIRE(links.size() == 0);
 }
 
@@ -419,7 +485,7 @@ TEST_CASE("<img> results in a placeholder and a link", "[HtmlRenderer]")
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 4);
-	REQUIRE(lines[0] == p(LineType::wrappable, "[image 1]"));
+	REQUIRE(lines[0] == p(LineType::wrappable, "[image 1 (link #1)]"));
 	REQUIRE(lines[1] == p(LineType::wrappable, ""));
 	REQUIRE(lines[2] == p(LineType::wrappable, "Links: "));
 	REQUIRE(lines[3] ==
@@ -430,20 +496,110 @@ TEST_CASE("<img> results in a placeholder and a link", "[HtmlRenderer]")
 	REQUIRE(links[0].second == LinkType::IMG);
 }
 
-TEST_CASE("<img>s without `src' are ignored", "[HtmlRenderer]")
+TEST_CASE(
+	"<img> results in a placeholder with the correct index, "
+	"and a link",
+	"[HtmlRenderer]")
 {
 	HtmlRenderer r;
 
-	const std::string input = "<img></img>";
+	const std::string input =
+		"<a href='http://example.com/index.html'>My Page</a>"
+		" and an image: "
+		"<img src='http://example.com/image.png'></img>";
 	std::vector<std::pair<LineType, std::string>> lines;
 	std::vector<LinkPair> links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
-	REQUIRE(lines.size() == 0);
-	REQUIRE(links.size() == 0);
+	REQUIRE(lines.size() == 5);
+	REQUIRE(lines[0] == p(LineType::wrappable,
+			"<u>My Page</>[1] and an image: [image 1 (link #2)]"));
+	REQUIRE(lines[1] == p(LineType::wrappable, ""));
+	REQUIRE(lines[2] == p(LineType::wrappable, "Links: "));
+	REQUIRE(lines[3] == p(LineType::softwrappable,
+			"[1]: http://example.com/index.html (link)"));
+	REQUIRE(lines[4] == p(LineType::softwrappable,
+			"[2]: http://example.com/image.png (image)"));
+	REQUIRE(links.size() == 2);
+	REQUIRE(links[0].first == "http://example.com/index.html");
+	REQUIRE(links[0].second == LinkType::HREF);
+	REQUIRE(links[1].first == "http://example.com/image.png");
+	REQUIRE(links[1].second == LinkType::IMG);
 }
 
-TEST_CASE("title is mentioned in placeholder if <img> has `title'",
+TEST_CASE(
+	"<img>s without `src', or with empty `src', are ignored",
+	"[HtmlRenderer]")
+{
+	HtmlRenderer r;
+
+	const std::string input =
+		"<img></img>"
+		"<img src=''></img>"
+		"<img src='http://example.com/image.png'>";
+	std::vector<std::pair<LineType, std::string>> lines;
+	std::vector<LinkPair> links;
+
+	REQUIRE_NOTHROW(r.render(input, lines, links, url));
+	REQUIRE(lines.size() == 4);
+	REQUIRE(lines[0] == p(LineType::wrappable, "[image 1 (link #1)]"));
+	REQUIRE(lines[1] == p(LineType::wrappable, ""));
+	REQUIRE(lines[2] == p(LineType::wrappable, "Links: "));
+	REQUIRE(lines[3] == p(LineType::softwrappable,
+			"[1]: http://example.com/image.png (image)"));
+	REQUIRE(links.size() == 1);
+}
+
+TEST_CASE("alt is mentioned in placeholder if <img> has `alt'",
+	"[HtmlRenderer]")
+{
+	HtmlRenderer r;
+
+	const std::string input =
+		"<img src='http://example.com/image.png'"
+		"alt='Just a test image'></img>";
+	std::vector<std::pair<LineType, std::string>> lines;
+	std::vector<LinkPair> links;
+
+	REQUIRE_NOTHROW(r.render(input, lines, links, url));
+	REQUIRE(lines.size() == 4);
+	REQUIRE(lines[0] == p(LineType::wrappable,
+			"[image 1: Just a test image (link #1)]"));
+	REQUIRE(lines[1] == p(LineType::wrappable, ""));
+	REQUIRE(lines[2] == p(LineType::wrappable, "Links: "));
+	REQUIRE(lines[3] == p(LineType::softwrappable,
+			"[1]: http://example.com/image.png (image)"));
+	REQUIRE(links.size() == 1);
+	REQUIRE(links[0].first == "http://example.com/image.png");
+	REQUIRE(links[0].second == LinkType::IMG);
+}
+
+TEST_CASE("alt is mentioned in placeholder if <img> has `alt' and `title",
+	"[HtmlRenderer]")
+{
+	HtmlRenderer r;
+
+	const std::string input =
+		"<img src='http://example.com/image.png'"
+		"alt='Just a test image' title='Image title'></img>";
+	std::vector<std::pair<LineType, std::string>> lines;
+	std::vector<LinkPair> links;
+
+	REQUIRE_NOTHROW(r.render(input, lines, links, url));
+	REQUIRE(lines.size() == 4);
+	REQUIRE(lines[0] == p(LineType::wrappable,
+			"[image 1: Just a test image (link #1)]"));
+	REQUIRE(lines[1] == p(LineType::wrappable, ""));
+	REQUIRE(lines[2] == p(LineType::wrappable, "Links: "));
+	REQUIRE(lines[3] == p(LineType::softwrappable,
+			"[1]: http://example.com/image.png (image)"));
+	REQUIRE(links.size() == 1);
+	REQUIRE(links[0].first == "http://example.com/image.png");
+	REQUIRE(links[0].second == LinkType::IMG);
+}
+
+TEST_CASE(
+	"title is mentioned in placeholder if <img> has `title' but not `alt'",
 	"[HtmlRenderer]")
 {
 	HtmlRenderer r;
@@ -457,7 +613,7 @@ TEST_CASE("title is mentioned in placeholder if <img> has `title'",
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 4);
 	REQUIRE(lines[0] ==
-		p(LineType::wrappable, "[image 1: Just a test image]"));
+		p(LineType::wrappable, "[image 1: Just a test image (link #1)]"));
 	REQUIRE(lines[1] == p(LineType::wrappable, ""));
 	REQUIRE(lines[2] == p(LineType::wrappable, "Links: "));
 	REQUIRE(lines[3] ==
@@ -484,7 +640,7 @@ TEST_CASE(
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
 	REQUIRE(lines.size() == 4);
-	REQUIRE(lines[0] == p(LineType::wrappable, "[image 1]"));
+	REQUIRE(lines[0] == p(LineType::wrappable, "[image 1: Red dot (link #1)]"));
 	REQUIRE(lines[1] == p(LineType::wrappable, ""));
 	REQUIRE(lines[2] == p(LineType::wrappable, "Links: "));
 	REQUIRE(lines[3] ==
@@ -1249,13 +1405,20 @@ TEST_CASE("<video>s without valid sources are ignored", "[HtmlRenderer]")
 	HtmlRenderer r;
 
 	const std::string input = "<video></video>"
-		"<video><source><source></video>";
+		"<video><source><source></video>"
+		"<video src=''></video>"
+		"<video src='http://example.com/video.avi'></video>";
 	std::vector<std::pair<LineType, std::string>> lines;
 	std::vector<LinkPair> links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
-	REQUIRE(lines.size() == 0);
-	REQUIRE(links.size() == 0);
+	REQUIRE(lines.size() == 4);
+	REQUIRE(lines[0] == p(LineType::wrappable, "[video 1 (link #1)]"));
+	REQUIRE(lines[1] == p(LineType::wrappable, ""));
+	REQUIRE(lines[2] == p(LineType::wrappable, "Links: "));
+	REQUIRE(lines[3] == p(LineType::softwrappable,
+			"[1]: http://example.com/video.avi (video)"));
+	REQUIRE(links.size() == 1);
 }
 
 TEST_CASE("<audio> results in a placeholder and a link for each valid source",
@@ -1302,13 +1465,20 @@ TEST_CASE("<audio>s without valid sources are ignored", "[HtmlRenderer]")
 	HtmlRenderer r;
 
 	const std::string input = "<audio></audio>"
-		"<audio><source><source></audio>";
+		"<audio><source><source></audio>"
+		"<audio src=''></audio>"
+		"<audio src='http://example.com/audio.oga'></audio>";
 	std::vector<std::pair<LineType, std::string>> lines;
 	std::vector<LinkPair> links;
 
 	REQUIRE_NOTHROW(r.render(input, lines, links, url));
-	REQUIRE(lines.size() == 0);
-	REQUIRE(links.size() == 0);
+	REQUIRE(lines.size() == 4);
+	REQUIRE(lines[0] == p(LineType::wrappable, "[audio 1 (link #1)]"));
+	REQUIRE(lines[1] == p(LineType::wrappable, ""));
+	REQUIRE(lines[2] == p(LineType::wrappable, "Links: "));
+	REQUIRE(lines[3] == p(LineType::softwrappable,
+			"[1]: http://example.com/audio.oga (audio)"));
+	REQUIRE(links.size() == 1);
 }
 
 TEST_CASE("Unclosed <video> and <audio> tags are closed upon encounter with a "
@@ -1483,3 +1653,35 @@ TEST_CASE("Skips contents of <script> tags", "[HtmlRenderer]")
 	REQUIRE(lines.size() == 0);
 	REQUIRE(links.size() == 0);
 }
+
+TEST_CASE("<div> is always rendered on a new line", "[HtmlRenderer]")
+{
+	HtmlRenderer rnd;
+	std::vector<std::pair<LineType, std::string>> lines;
+	std::vector<LinkPair> links;
+
+	const std::string
+	input("<div>oh</div>"
+		"<div>hello there,</div>"
+		"<p>world</p>"
+		"<div>!</div>"
+		"<div>"
+		"    <div>"
+		"        <p>hehe</p>"
+		"    </div>"
+		"</div>");
+
+	rnd.render(input, lines, links, "");
+
+	REQUIRE(lines.size() == 9);
+	REQUIRE(lines[0] == p(LineType::wrappable, "oh"));
+	REQUIRE(lines[1] == p(LineType::wrappable, ""));
+	REQUIRE(lines[2] == p(LineType::wrappable, "hello there,"));
+	REQUIRE(lines[3] == p(LineType::wrappable, ""));
+	REQUIRE(lines[4] == p(LineType::wrappable, "world"));
+	REQUIRE(lines[5] == p(LineType::wrappable, ""));
+	REQUIRE(lines[6] == p(LineType::wrappable, "!"));
+	REQUIRE(lines[7] == p(LineType::wrappable, ""));
+	REQUIRE(lines[8] == p(LineType::wrappable, "hehe"));
+	REQUIRE(links.size() == 0);
+}
