@@ -57,7 +57,7 @@ TEST_CASE("item_renderer::to_plain_text() produces a rendered representation "
 	"of an RSS item, ready to be displayed to the user",
 	"[item_renderer]")
 {
-	TestHelpers::EnvVar tzEnv("TZ");
+	TestHelpers::TzEnvVar tzEnv;
 	tzEnv.set("UTC");
 
 	ConfigContainer cfg;
@@ -161,7 +161,7 @@ TEST_CASE("item_renderer::to_plain_text() renders text to the width specified "
 	"in `text-width` setting",
 	"[item_renderer]")
 {
-	TestHelpers::EnvVar tzEnv("TZ");
+	TestHelpers::TzEnvVar tzEnv;
 	tzEnv.set("UTC");
 
 	ConfigContainer cfg;
@@ -268,7 +268,7 @@ TEST_CASE("item_renderer::to_plain_text() renders text to the width specified "
 TEST_CASE("to_plain_text() does not escape '<' and '>' in header and body",
 	"[item_renderer]")
 {
-	TestHelpers::EnvVar tzEnv("TZ");
+	TestHelpers::TzEnvVar tzEnv;
 	tzEnv.set("UTC");
 
 	ConfigContainer cfg;
@@ -300,7 +300,7 @@ TEST_CASE("to_plain_text() does not escape '<' and '>' in header and body",
 
 TEST_CASE("Empty fields are not rendered", "[item_renderer]")
 {
-	TestHelpers::EnvVar tzEnv("TZ");
+	TestHelpers::TzEnvVar tzEnv;
 	tzEnv.set("UTC");
 
 	ConfigContainer cfg;
@@ -416,7 +416,7 @@ TEST_CASE("Empty fields are not rendered", "[item_renderer]")
 TEST_CASE("item_renderer::to_plain_text honours `html-renderer` setting",
 	"[item_renderer]")
 {
-	TestHelpers::EnvVar tzEnv("TZ");
+	TestHelpers::TzEnvVar tzEnv;
 	tzEnv.set("UTC");
 
 	ConfigContainer cfg;
@@ -601,7 +601,7 @@ TEST_CASE("item_renderer::get_feedtitle() returns item's feed URL "
 TEST_CASE("Functions used for rendering articles escape '<' into `<>` for use with stfl",
 	"[item_renderer]")
 {
-	TestHelpers::EnvVar tzEnv("TZ");
+	TestHelpers::TzEnvVar tzEnv;
 	tzEnv.set("UTC");
 
 	ConfigContainer cfg;
@@ -656,3 +656,80 @@ TEST_CASE("Functions used for rendering articles escape '<' into `<>` for use wi
 		REQUIRE(result.first == expected);
 	}
 }
+
+TEST_CASE("item_renderer::render_plaintext() splits text on newlines", "[item_renderer]")
+{
+	using newsboat::item_renderer::OutputFormat;
+	// Verifies that render_plaintext creates the expected lines, all marked as wrappable
+	const auto check = [](const std::string input,
+	const std::vector<std::string>& expected_lines, OutputFormat format) {
+		std::vector<std::pair<LineType, std::string>> output;
+		item_renderer::render_plaintext(input, output, format);
+
+		REQUIRE(output.size() == expected_lines.size());
+		for (std::size_t i = 0; i < output.size(); ++i) {
+			INFO("i: " + std::to_string(i));
+			REQUIRE(output[i].first == LineType::wrappable);
+			REQUIRE(output[i].second == expected_lines[i]);
+		}
+	};
+
+	SECTION(R"(regular text is split on \r and \n)") {
+		const std::string text =
+			"Lorem ipsum dolor sit amet\nconsectetur adipiscing elit\rsed do eiusmod tempor incididunt ut labore\net dolore magna aliqua.";
+
+		check(text, {
+			"Lorem ipsum dolor sit amet",
+			"consectetur adipiscing elit",
+			"sed do eiusmod tempor incididunt ut labore",
+			"et dolore magna aliqua."
+		}, OutputFormat::StflRichText);
+	}
+
+	SECTION("render_plaintext keeps indentation") {
+		const std::string text =
+			"The following lines are indented:\n    hello\n    this is a test\n\nback to no indentation";
+
+		check(text, {
+			"The following lines are indented:",
+			"    hello",
+			"    this is a test",
+			"",
+			"back to no indentation"
+		}, OutputFormat::StflRichText);
+	}
+
+	SECTION(R"(text is split on sequences of \r\n, and on separate \r and \n characters)") {
+		const std::string text =
+			"Lorem ipsum\r\ndolor sit amet\n\rconsectetur adipiscing elit\rsed do eiusmod tempor incididunt ut labore\net dolore magna\r\n\r\naliqua.";
+
+		check(text, {
+			"Lorem ipsum",
+			"dolor sit amet",
+			"",
+			"consectetur adipiscing elit",
+			"sed do eiusmod tempor incididunt ut labore",
+			"et dolore magna",
+			"",
+			"aliqua."
+		}, OutputFormat::StflRichText);
+	}
+
+	SECTION("render_plaintext escapes angle brackets for STFL") {
+		const std::string text = "this < should be escaped >\n<p>test text</p>";
+
+		check(text, {
+			"this <> should be escaped >",
+			"<>p>test text<>/p>"
+		}, OutputFormat::StflRichText);
+	}
+
+	SECTION("render_plaintext does not escape when rendering towards some plaintext output") {
+		const std::string text = "this < should *not* be escaped >\n<p>test text</p>";
+
+		check(text, {
+			"this < should *not* be escaped >",
+			"<p>test text</p>"
+		}, OutputFormat::PlainText);
+	}
+}
